Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(29)

Unified Diff: vm/scopes.cc

Issue 10539108: First step to SSA construction: Phi insertion. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: addressed comments, fixed bug in BitVector::Contains Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vm/scopes.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/scopes.cc
===================================================================
--- vm/scopes.cc (revision 8546)
+++ vm/scopes.cc (working copy)
@@ -480,8 +480,8 @@
}
-// Map the frame index into an index in the range 0..(vector->length()-1).
-int LocalVariable::BitIndexIn(BitVector* vector) const {
+// Map the frame index into an index in the range 0..(var_count-1).
+int LocalVariable::BitIndexIn(intptr_t var_count) const {
ASSERT(!is_captured());
// Parameters have positive indexes with the lowest index being 2. Locals
// and copied parameters have negative indexes with the lowest (closest to
@@ -492,7 +492,7 @@
} else {
// Shift negative indexes so that the lowest one is 0 (they are still
// non-positive) and index them backward from the end of the vector.
- return (vector->length() - 1) +
+ return (var_count - 1) +
(index() - ParsedFunction::kFirstLocalSlotIndex);
}
}
« no previous file with comments | « vm/scopes.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698